@@ -52,7 +52,8 @@
 #' @example examples/in_case.R
 
 in_case <- function(..., preserve = FALSE, default = NA) {
-  inputs <- in_case_setup(..., preserve = preserve, fn = "in_case()")
+  dots <- allow_dot_aliases(compact_list(...))
+  inputs <- in_case_setup(dots, preserve = preserve, fn = "in_case")
 
   replace(
     fs          = inputs$fs,
@@ -64,14 +65,16 @@ in_case <- function(..., preserve = FALSE, default = NA) {
   )
 }
 
-in_case_setup <- function(..., preserve, fn) {
-  ellipsis <- compact_list(...)
+in_case_setup <- function(dots, preserve, fn) {
+  if (length(dots) == 0) {
+    return(list(fs = list(), x = vector()))
+  }
 
-  if (!rlang::is_formula(ellipsis[[1]])) {
-    fs <- ellipsis[-1]
-    x  <- ellipsis[[1]]
+  if (!rlang::is_formula(dots[[1]])) {
+    fs <- dots[-1]
+    x  <- dots[[1]]
   } else {
-    fs <- ellipsis
+    fs <- dots
     x  <- NULL
     assert_no_preserve_without_pipe(preserve, fn)
   }
@@ -83,16 +86,15 @@ in_case_setup <- function(..., preserve, fn) {
 
 assert_no_preserve_without_pipe <- function(preserve, fn) {
   if (preserve) {
-    abort_msg(
-      paste(
-        "A vector must be piped into", code(fn),
-        "to use", code("preserve")
-      ),
-      paste("Try using", code("default"), "instead")
-    )
+    cli::cli_abort(c(
+      "The first argument to {.fn {fn}} must be a vector
+      to use the {.arg preserve} argument.",
+      "*" = "Try using {.arg default} instead."
+    ))
   }
 }
 
+#' @importFrom plu ral
 assert_two_sided <- function(fs, fn) {
   nfs <- Filter(
     function(fs) !rlang::is_formula(fs, lhs = TRUE) && !rlang::is_quosure(fs),
@@ -100,12 +102,9 @@ assert_two_sided <- function(fs, fn) {
   )
 
   if (length(nfs)) {
-    abort_msg(
-      paste("Each argument to", code(fn), "must be a two-sided formula"),
-      x = paste(
-        plu::stick(plu::more(code(nfs), 5, "argument")),
-        plu::ral("is {not} a {two-sided} formula.", nfs)
-      )
-    )
+    cli::cli_abort(c(
+      "Each argument to {.fn {fn}} must be a two-sided formula.",
+      x = "{.code {nfs}} {plu::ral('is {not} a {two-sided} formula.', nfs)}."
+    ))
   }
 }
