@@ -2,16 +2,6 @@ words  <- c("caterpillar", "dogwood", "catastrophe", "dogma")
 result <- c("feline", "canine", "feline", "canine")
 
 test_that("function and lambda equivalent", {
-  expect_equal(
-    fn_case(
-      words,
-      fn = stringi::stri_detect_regex,
-      "cat" ~ "feline",
-      "dog" ~ "canine"
-    ),
-    result
-  )
-
   expect_equal(
     fn_case(
       words,
@@ -44,17 +34,6 @@ test_that("function and lambda equivalent", {
 })
 
 test_that("fn_case() ignore.case", {
-  expect_equal(
-    fn_case(
-      words,
-      fn = stringi::stri_detect_regex,
-      "cat" ~ "feline",
-      "dog" ~ "canine",
-      case_insensitive = TRUE
-    ),
-    result
-  )
-
   expect_equal(
     fn_case(
       words,
